print.gvlma invokes print on the lm object and then calls
display.gvlmatests.
summary.gvlma invokes summary on the lm object with the
additional … arguments and then calls
display.gvlmatests.
display.gvlmatests provides the test statistics, p-values and decision
(whether linear models assumptions are satisfied) for the global and
directional tests associated with the gvlma object. The decision is
reported at the level of significance used when the gvlma object was
created. See the argument alphalevel to gvlma.